;========================================================
;===		"The Legend of Amber"		      ===
;===						      ===
;===	 	(c) Luca Pavan - 2002		      ===
;===		  revised July 2013		      ===
;===						      ===
;===	  	   Duration: 9'19"		      ===
;========================================================

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;This  piece  is a musical comment on the subject of an =
;ancient  Lithuanian  folk legend, very much popular in =
;Lithuania.  The  legend is based on the forbidden love =
;between  a  fisherman  (Kastytis) and a goddess of the =
;sea  (Jurate),  their joy into a beatiful amber palace =
;under  the  sea, with a dramatic ending when the amber =
;palace is destroyed and the fisherman is killed by the =
;god  Perkunas.  According to the legend, the pieces of =
;amber,  so easy to find on the Baltic coast, come from =
;the  amber  palace.  The first time I have heard about =
;this  legend  I  was  surprised to find a typical plot =
;that  often  appears in ancient myths, literature, and =
;theatre  of  European  culture.  So  I was inspired to =
;write a piece about it.                                =
;For this work I designed sixteen different algorithms, =
;dividing the piece in three parts: the meeting between =
;Jurate  and  Kastytis,  the  celebrations in the amber =
;palace,  the wrath of Perkunas. The algorithms include =
;the following techniques: additive Synthesis, ring and =
;frequency modulation, FOF synthesis, filtered noise.   =
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

sr =96000
kr =96000
ksmps = 1
nchnls= 2

#define E(A) #

ad1 init 0
ad3 init 0
ad5 init 0
ad7 init 0
ad9 init 0

ig=0.01

as1 butbp al,50,60
ad1 delay as1+ig*(ad1-ig*as1),.01
as2 butbp al,200,240
as3 butbp al,800,960
ad3 delay as3+ig*(ad3-ig*as3),.01
as4 butbp al,3200,3840
as5 butbp al,12800,15360
ad5 delay as5+ig*(ad5-ig*as5),.01
as6 butbp ar,50,60
as7 butbp ar,200,240
ad7 delay as7+ig*(ad7-ig*as7),.01
as8 butbp ar,800,960
as9 butbp ar,3200,3840
ad9 delay as9+ig*(ad9-ig*as9),.01
asa butbp ar,12800,15360
ao1=(ad1+as2+ad3+as4+ad5)*1.3
ao2=(as6+ad7+as8+ad9+asa)*1.3
aol=(al*(1-$A.))+(ao1*$A.)
aor=(ar*(1-$A.))+(ao2*$A.) #

gar init 0

instr 1

ka  linen 1,p3*.25,p3,p3*.25
ke  line 100,p3,5000
kv  line 5000,p3,100
kx  randi p4,5
ky  randi p5,10
k2  gauss 50
k3  randi 1,abs(k2)
a1  rand 10000
a2  delay a1,.005
a3 =a1+a2
a4  butterbp a3,ke,abs(kx)
a5  butterbp a3,kv,abs(ky)
a6 =a4+a5
as  delay a6,.1
al =(as*.3*abs(k3))+as*.5*ka
ar =(as*.3*(1-abs(k3)))+as*.5*ka
gar=gar+(al*p6)+(ar*p6)
$E(1)
  outs aol*(1-p6),aor*(1-p6)
   endin

instr 2

an linen 9000,.2,p3,4
k2 expseg 100,p3*.85,12000,p3*.15,11000
k1 randh k2,5
a1 rand an
k1 =abs(k1)
a2 reson a1,k1,250
a3 reson a1,k1*2,175
a4 reson a1,k1*1.7,150
a5 reson a1,k1*3,100
a6 reson a1,k1*3.2,75
as =a2+(a3*.8)+(a4*.6)+(a5*.4)+(a6*.2)
ab balance as,a1
al =ab*.7*(1-p4)
ar =ab*.7*p4
gar=gar+(al*p5)+(ar*p5)
  outs al*(1-p5),ar*(1-p5)
   endin

instr 3

ke linen p4*1.5,4,p3,5
k1 expseg 150,p3*.25,180,p3*.25,200,p3*.25,300,p3*.25,150
k2 expseg 40,p3*.25,120,p3*25,350,p3*.25,350,p3*.25,250
a1 rand 15000
a2 butterbp a1,k1,k2
a3 tone a2,600
al =a3*ke*(1-p5)
ar =a3*ke*p5
gar=gar+(al*p6)+(ar*p6)
  outs al*(1-p6),ar*(1-p6)
   endin

instr 4

#define M # .003,.02,.007,2000,1,3,p3 #

if p82=1 goto cnt1
kf1=cpspch(p5)
kf2=cpspch(p5)
kf3=cpspch(p5)
kf4=cpspch(p5)

if p82!=1 goto cnt2

cnt1:
kv1  randi 179,5,.5,1
kv2  randi 204,8,.8,1
kv3  randi 183,10,.2,1
kv4  randi 660,15,.3,1

kf1=66+abs(kv1)
kf2=124+abs(kv2)
kf3=165+abs(kv3)
kf4=220+abs(kv4)

cnt2:
ka linen p6*1.9,.25,p3,p7
ke linen 1,.25,p3,.1
kc randi 1,1
k1 poscil 1,p80/p3,p81

if p79=1 goto outa
if p79=2 goto oute
if p79=3 goto outi
if p79=4 goto outo
if p79=5 goto outu

outa:
a1 fof p4,kf1,p9,kc,p14,$M.
a2 fof p4*p19,kf1,p10,kc,p15,$M.
a3 fof p4*p20,kf1,p11,kc,p16,$M.
a4 fof p4*p21,kf1,p12,kc,p17,$M.
a5 fof p4*p22,kf1,p13,kc,p18,$M.
a6 =a1+a2+a3+a4+a5
as =a6*k1*ka
goto end

oute:
a7  fof p4,kf2,p23,kc,p28,$M.
a8  fof p4*p33,kf2,p24,kc,p29,$M.
a9  fof p4*p34,kf2,p25,kc,p30,$M.
a10 fof p4*p35,kf2,p26,kc,p31,$M.
a11 fof p4*p36,kf2,p27,kc,p32,$M.
a12 =a7+a8+a9+a10+a11
as  =a12*k1*ka
goto end

outi:
a13 fof p4,kf1,p37,kc,p42,$M.
a14 fof p4*p47,kf1,p38,kc,p43,$M.
a15 fof p4*p48,kf1,p39,kc,p44,$M.
a16 fof p4*p49,kf1,p40,kc,p45,$M.
a17 fof p4*p50,kf1,p41,kc,p46,$M.
a18 =a13+a14+a15+a16+a17
as  =a18*k1*ka
goto end

outo:
a19 fof p4,kf3,p51,kc,p56,$M.
a20 fof p4*p61,kf3,p52,kc,p57,$M.
a21 fof p4*p62,kf3,p53,kc,p58,$M.
a22 fof p4*p63,kf3,p54,kc,p59,$M.
a23 fof p4*p64,kf3,p55,kc,p60,$M.
a24 =a19+a20+a21+a22+a23
as  =a24*k1*ka
goto end

outu:
a25 fof p4,kf4,p65,kc,p70,$M.
a26 fof p4*p75,kf4,p66,kc,p71,$M.
a27 fof p4*p76,kf4,p67,kc,p72,$M.
a28 fof p4*p77,kf4,p68,kc,p73,$M.
a29 fof p4*p78,kf4,p69,kc,p74,$M.
a30 =a25+a26+a27+a28+a29
as  =a30*k1*ka

end:
ad delay as,.06
al =as*(1-p8)
ar =ad*ke*p8
gar=gar+(al*.15)+(ar*.15)
$E(1)
  outs aol*.75,aor*.75
   endin

instr 5

ke  linen 1.5,5,p3,5
kd  poscil 1,1/p3,4
k1  randh p5,10
k2  expseg 60,p3*.5,850,p3*.25,550,p3*.25,60
kj1 randh 10,10
km  poscil (40+abs(k1)*2)*1.1,40+abs(k1),1
kc  poscil p4,(40+abs(k1)*10)+km,1
a1  upsamp kc
a2  poscil 1,k2+abs(kj1),1
al =a1*a2*kd*ke*(1-p6)
ar =a1*a2*kd*ke*p6
gar=gar+(al*p7)+(ar*p7)
  outs al*(1-p7),ar*(1-p7)
   endin

instr 6

#define F # k7,1,1,1 #

ke linen 1.5,.02,p3,.02
k1 expseg .001,1,p4*.2,p3-1,.001
k2 expseg .001,1.5,p4*.2,p3-1.5,.001
k3 expseg .001,2,p4*.2,p3-2,.001
k4 expseg .001,2.5,p4*.2,p3-2.5,.001
k5 expseg .001,3,p4*.2,p3-3,.001
k6 randi 1,2
k7 line p6,p3,p7
km1 poscil k7*1.1,k7,1
kc1 poscil k1,p5+km1,1
km2 poscil k7*1.1,k7,1
kc2 poscil k2,(p5-2)+km2,1
km3 poscil k7*1.1,k7,1
kc3 poscil k3,(p5-3)+km3,1
km4 poscil k7*1.1,k7,1
kc4 poscil k4,(p5+10)+km4,1
km5 poscil k7*1.1,k7,1
kc5  poscil k5,(p5+9)+km5,1
a6 upsamp kc1+kc2+kc3+kc4+kc5
al =a6*(1-abs(k6))*ke
ar =a6*abs(k6)*ke
gar=gar+(al*p8)+(ar*p8)
  outs al*(1-p8),ar*(1-p8)
   endin

instr 7

a4 init 0

ke linen 1.2,.01,p3,.01
k1 linseg 0,.05,1,.05,.5,p3*.1-.1,.5,p3*.05,0
k2 line 1,p3,cpspch(p8)
k4 randi 1,3 
a1 poscil k1*p4,cpspch(p5)+k2,1
a2 poscil 1,cpspch(p6),1
a3 =a1*a2
a4 delay (a3+a4)*.7,p7
al =(a3+a4)*ke*abs(k4)
ar =(a3+a4)*ke*(1-abs(k4))
gar=gar+(al*p9)+(ar*p9)
  outs al*(1-p9),ar*(1-p9)
   endin

instr 8

ke  linen 1.3,.01,p3,.01
k1  linen p4,p3*.35,p3,p3*.3
k2  line  10,p3,4
k3  randi k2,1
k4  randi 100,1.5
k5  randi 200,2
k6  linseg .01,p3*.5,100,p3*.5,.01
k7  randi 1,k6
ki1 expon .001,p3,10
ki2 expon 10,p3,.001
ki3 linseg 0,p3*.5,5,p3*.5,0
am1 poscil ki1*(p6+k3),p6,1
am2 poscil ki2*(p7+k4),p7,1
am3 poscil ki3*(p8+k5),p8,1
ac1 poscil k1,p5+am1+am2+am3,1
aff butterbp ac1,4000,19000
af1 butterhp aff,75
al =af1*abs(k7)*ke
ar =af1*(1-abs(k7))*ke
gar=gar+(al*p9)+(ar*p9)
  outs al*(1-p9),ar*(1-p9)
   endin

instr 9

k3 linseg p7,p3*.25,p7,0,p8,p3*.25,p8,0,p7,p3*.25,p7,0,p8,p3*.25,p8
k2 randi 1,2
ke linen 1.2,.01,p3,.2
if p9 !=0 goto c1
k1 poscil p4,k3/p3,2
goto c2
c1:
k1 poscil p4,1/p3,2
c2:
a2 poscil 1,p5,1
a3 poscil 1,p6,1
a4 =a2*a3
a5 butterhp a4,70
al =a5*k1*ke*abs(k2)
ar =a5*k1*ke*(1-abs(k2))
az delay al,.07
  outs az,ar
   endin

instr 10

ke linen p4,.05,p3,.5
k1 linseg p6,p3*.5,p6+2000,p3*.5,p6
k2 randi 1000,2
ka line p7,p3,p8
k3 poscil 1,ka/p3,5
k4 poscil 1,ka/p3,6
k5 expon 50,p3,200
km1 poscil p6*5,p6,1
kc1 poscil ke,p5+km1,1
a1 upsamp kc1
a2 butterbp a1,k1,k5
a3 butterbp a1,k1*2,k5*2
a4 =a2+a3
if p9 !=0 goto inv
gar=gar+(a4*k4)+(a4*k3)*.4*p10
 outs a4*k4*(1-p10),a4*k3*(1-p10)
   goto end
inv:
gar=gar+(a4*k4)+(a4*k3)*.5*p10
 outs a4*k3*(1-p10),a4*k4*(1-p10)
end:
   endin

instr 11

kn linen 1.4,.01,p3,.01
kc expseg 1,p3*.5,p6,p3*.5,1
kg line 8000,p3,1
ke poscil p4,1/p3+kc,2
kp expseg .001,.02,1,p3-.02,.001
k1 line 6,p3,1
k2 randh kg,14
k3 randi 30,2
k4 randi 1,10
k5 poscil 1,k3/p3,1
a1 poscil k1*k2,p5+k2,1
a2 poscil ke*kp,abs(k2)*3+a1+k5,1
a3 butterhp a2,11000
al =a3*kn*abs(k4)
ar =a3*kn*(1-abs(k4))
gar=gar+(al*p7)+(ar*p7)
  outs al*(1-p7),ar*(1-p7)
   endin

instr 12

ka  expseg .001,p3*.1,p4,p3-.1,.001
kb  expseg .001,p3*.1,1,p3-.1,.001
k1  expon 100,10/p3,200
k2  expon 200,p3,1000
k3  poscil 1,1/p3,1
k4  randi 50,1/p3
k5  poscil 1,1/p3,5
k6  poscil 1,1/p3,6
kf  expon p5,p3,p6
a1  poscil 1,60,1
a2  poscil 1,1+k1,1
a3  poscil ka,kf,1
a4  rand 10000
a5  butterbp a4,k2,k3+abs(k4)
al =(a1*a2*a3)+(a5*kb*k5)
ar =(a1*a2*a3)+(a5*kb*k6)
alx butterbp al,10000,19900
ary butterbp ar,10000,19000
all reverb2 alx,2,0
alr reverb2 ary,2.1,0
if p7 !=0 goto c2
gar=gar+(al*.2)+(ar*.2)
  outs alx+all*.8,ary+alr*.8
  goto end
c2:
gar=gar+(al*.2)+(ar*.2)
  outs ary+alr*.8,alx+all*.8
end:
   endin

instr 13

kn linen 1,.01,p3,.01
ke expseg .001,p9,p4,p3-p9,.001
kv linseg 0,.3,0,.1,1,p3-.7,1,.3,0
k1 poscil p6,1/p3,7
k2 poscil p8,1/p3,7
k3 randi 1,p10
a1 rand 15000
a2 butterbp a1,p5+k1,p7+k2
a3 poscil 1,1/p3,7
a4 =a2*a3
a5 comb a4,.1,.05
ax balance a4,a1
ay balance a5,a1
al =ax*ke*kn*abs(k3)
ar =ay*ke*kn*kv*(1-abs(k3))
gar=gar+(al*p11)+(ar*p11)
  outs al*(1-p11),ar*(1-p11)
   endin

instr 14

ke  line p6,p3,p7
ka  linen 1.2,.02,p3,.02
k1  expseg .001,p3*.1,1,p3-p3*.1,.001
k2  expseg .001,p3*.25,1,p3-p3*.25,.001
k3  expseg .001,p3*.4,1,p3-p3*.4,.001
k4  expseg .001,p3*.65,1,p3-p3*.65,.001
k5  expseg .001,p3*.8,1,p3-p3*.8,.001
k6  expseg .001,p3*.95,1,p3-p3*.95,.001
k7  randi 40,1
k8  randi 30,1
k9  randi 20,1
k10 randi 10,1
k11 randi 5,1
a1 poscil p4*k1,p5+ke,1
a2 poscil p4*k2,p5+k7+ke,1
a3 poscil p4*k3,p5-k8+ke,1
a4 poscil p4*k4,p5+k9+ke,1
a5 poscil p4*k5,p5-k10+ke,1
a6 poscil p4*k6,p5+k11+ke,1
a7 =a1+a2+a3+a4+a5+a6
a8 poscil 1,p5*2+ke,1
a9 =a7*a8
af reson a9,4000,1000
ab balance af,a1
az butterhp ab,70
az =az*ka
gar=gar+az*.4*p8
  outs az*(1-p8),az*(1-p8)
   endin

instr 15

ke linen p4,.02,p3,1.5
kp line 8,p3,1/p3
kv randh 240,kp
k1 line 4000,p3,1
k2 randi k1,1
k3 poscil 1,abs(kv)/p3,8
k4 expon 1,p3,1/p3
k5 randi .9,k4
k6 expon p5,p3,p6
a1 rand 10000
a2 butterbp a1,k6+abs(k2),30
a3 comb a2*1.2,.01,.05
ay reverb2 a2,2,.5
al =a2*k3*ke*abs(k5)+(ay*.1)
ar =a3*k3*ke*(1-abs(k5))+(ay*.12)
gar=gar+(al*p7)+(ar*p7)
$E(.95)
  outs aol*(1-p7),aor*(1-p7)
   endin

instr 16

p5 =cpspch(p5)
ke linen 1,p8,p3,p9
k1 expon p4,p3,.001
k2 expon p4,p3*p7*.94,.001
k3 expon p4,p3*p7*.9,.001
k4 expon p4,p3*p7*.86,.001
k5 expon p4,p3*p7*.84,.001
k6 expon p4,p3*p7*.8,.001
k7 expon p4,p3*p7*.74,.001
k8 expon p4,p3*p7*.7,.001
a1 poscil k1,p5,1
a2 poscil k2*.6,p5*2,1
a3 poscil k3,p5*2.37,1
a4 poscil k4*1.76,p5*3,1
a5 poscil k5*2.6,p5*4,1
a6 poscil k6*1.6,p5*5.2,1
a7 poscil k7*1.43,p5*5.3,1
a8 poscil k8*1.33,p5*6,1
at =(a1+a2+a3+a4+a5+a6+a7+a8)*ke
as buthp at,50
gar=gar+(as*p10)
  outs as*(1-p6)*(1-p10),as*p6*(1-p10)
   endin

instr 99

adx  delayr  .25
at1  deltapi .0231
at2  deltapi .0222
at3  deltapi .0132
at4  deltapi .0134
at5  deltapi .1051
at6  deltapi .1024
at7  deltapi .0353
at8  deltapi .0324
at9  deltapi .0232
at10 deltapi .0232
at11 deltapi .1134
at12 deltapi .1123
at13 deltapi .0345
at14 deltapi .0345
at15 deltapi .0673
at16 deltapi .1233
at17 deltapi .1312
at18 deltapi .0637
at19 deltapi .0684
at20 deltapi .1163
at21 deltapi .1173
at22 deltapi .0275
at23 deltapi .0282
at24 deltapi .0297
     delayw gar     
as1  =at1+at2+at3+at4+at5+at6+at7+at8+at9+at10+at11+at12
as2  =at13+at14+at15+at16+at17+at18+at19+at20+at21+at22+at23+at24
arl  nreverb as1*.083,p4,0
arr  nreverb as2*.083,p4,0
km1  poscil 280,.02,1
km2  poscil 250,.023,1,.2
al1  butlp arl,12800+km1
ar1  butlp arr,12800+km2
al   balance al1,arl
ar   balance ar1,arr
kd   linseg .9,400.5,.9,1,1,155,1
$E(kd)
  outs aol,aor
gar= 0
   endin